==> dart_chainsql_api-1.0.5.tar.gz: lib/src/core/format/TxFormat.dart <==
import "./Format.dart";
import "../serialized/enums/TransactionType.dart";

import 'package:dart_chainsql_api/src/core/fields/Field.dart';

class TxFormat extends Format {
  static Map<TransactionType, TxFormat> formats =
      new Map<TransactionType, TxFormat>();
  TransactionType transactionType;

  static TxFormat fromString(String name) {
    return getTxFormat(TransactionType.valueOf(name));
  }

  static TxFormat fromNumber(num ord) {
    return getTxFormat(TransactionType.fromNumber(ord));
  }

  static TxFormat fromValue(Object o) {
    if (o.runtimeType == num) {
      return fromNumber(o as int);
    } else if (o.runtimeType == String) {
      return fromString(o as String);
    } else {
      return null;
    }
  }

  static TxFormat getTxFormat(TransactionType key) {
    if (key == null) return null;

    // TODO
    if (formats.isEmpty) {
      // init by call?
      Payment;
      TrustSet;
      SQLStatement;
    }

    return formats[key];
  }

  TxFormat(TransactionType type, List<Object> args) : super(args) {
    transactionType = type;
    addCommonFields();
    formats[transactionType] = this;
  }

  String name() {
    return transactionType.toString();
  }

  // @override
  void addCommonFields() {
    put(Field.TransactionType, Requirement.REQUIRED);
    put(Field.Account, Requirement.REQUIRED);
    put(Field.Sequence, Requirement.REQUIRED);
    put(Field.Fee, Requirement.REQUIRED);
    put(Field.SigningPubKey, Requirement.REQUIRED);

//    put(Field.Flags,               Requirement.OPTIONAL);
//    put(Field.SourceTag,           Requirement.OPTIONAL);
//    put(Field.PreviousTxnID,       Requirement.OPTIONAL);
//    put(Field.OperationLimit,      Requirement.OPTIONAL);
//    put(Field.TxnSignature,        Requirement.OPTIONAL);
//    put(Field.AccountTxnID,        Requirement.OPTIONAL);
//    put(Field.LastLedgerSequence,  Requirement.OPTIONAL);
//    put(Field.Memos,               Requirement.OPTIONAL);
//    put(Field.Signers,			       Requirement.OPTIONAL);
  }

//

  static TxFormat Payment = new TxFormat(TransactionType.Payment, [
    Field.Destination,
    Requirement.REQUIRED,
    Field.Amount,
    Requirement.REQUIRED,
    Field.SendMax,
    Requirement.OPTIONAL,
    Field.Paths,
    Requirement.DEFAULT,
    Field.InvoiceID,
    Requirement.OPTIONAL,
    Field.DestinationTag,
    Requirement.OPTIONAL
  ]);

  static TxFormat TrustSet = new TxFormat(TransactionType.TrustSet, [
    Field.LimitAmount,
    Requirement.OPTIONAL,
    Field.QualityIn,
    Requirement.OPTIONAL,
    Field.QualityOut,
    Requirement.OPTIONAL
  ]);

  static TxFormat SQLStatement = new TxFormat(TransactionType.SQLStatement, [
    Field.Owner,
    Requirement.REQUIRED,
    Field.Tables,
    Requirement.REQUIRED,
    Field.Raw,
    Requirement.REQUIRED,
    Field.OpType,
    Requirement.REQUIRED
  ]);


//  static TxFormat SQLStatement = new TxFormat(
//  TransactionType.SQLStatement,
//  Field.Owner,         Requirement.REQUIRED,
//  Field.Tables,        Requirement.REQUIRED,
//  Field.Raw,       	 Requirement.REQUIRED,
//  Field.AutoFillField, Requirement.OPTIONAL,
//  Field.TxCheckHash,	 Requirement.OPTIONAL,
//  Field.OpType, 		 Requirement.REQUIRED,
//  Field.TxnLgrSeq,	 Requirement.OPTIONAL,
//  Field.OriginalAddress,Requirement.OPTIONAL,
//  Field.CurTxHash,	 Requirement.OPTIONAL,
//  Field.FutureTxHash,	 Requirement.OPTIONAL);

}

==> dart_chainsql_api-1.0.8.tar.gz: lib/src/core/format/TxFormat.dart <==
import "./Format.dart";
import "../serialized/enums/TransactionType.dart";

import 'package:dart_chainsql_api/src/core/fields/Field.dart';

class TxFormat extends Format {
  static Map<TransactionType, TxFormat> formats =
      new Map<TransactionType, TxFormat>();
  TransactionType transactionType;

  static TxFormat fromString(String name) {
    return getTxFormat(TransactionType.valueOf(name));
  }

  static TxFormat fromNumber(num ord) {
    return getTxFormat(TransactionType.fromNumber(ord));
  }

  static TxFormat fromValue(Object o) {
    if (o.runtimeType == num) {
      return fromNumber(o as int);
    } else if (o.runtimeType == String) {
      return fromString(o as String);
    } else {
      return null;
    }
  }

  static TxFormat getTxFormat(TransactionType key) {
    if (key == null) return null;

    // TODO
    if (formats.isEmpty) {
      // init by call?
      Payment;
      TrustSet;
      SQLStatement;
    }

    return formats[key];
  }

  TxFormat(TransactionType type, List<Object> args) : super(args) {
    transactionType = type;
    addCommonFields();
    formats[transactionType] = this;
  }

  String name() {
    return transactionType.toString();
  }

  // @override
  void addCommonFields() {
    put(Field.TransactionType, Requirement.REQUIRED);
    put(Field.Account, Requirement.REQUIRED);
    put(Field.Sequence, Requirement.REQUIRED);
    put(Field.Fee, Requirement.REQUIRED);
    put(Field.SigningPubKey, Requirement.REQUIRED);

//    put(Field.Flags,               Requirement.OPTIONAL);
//    put(Field.SourceTag,           Requirement.OPTIONAL);
//    put(Field.PreviousTxnID,       Requirement.OPTIONAL);
//    put(Field.OperationLimit,      Requirement.OPTIONAL);
//    put(Field.TxnSignature,        Requirement.OPTIONAL);
//    put(Field.AccountTxnID,        Requirement.OPTIONAL);
    put(Field.LastLedgerSequence,  Requirement.OPTIONAL);
//    put(Field.Memos,               Requirement.OPTIONAL);
//    put(Field.Signers,			       Requirement.OPTIONAL);
  }

//

  static TxFormat Payment = new TxFormat(TransactionType.Payment, [
    Field.Destination,
    Requirement.REQUIRED,
    Field.Amount,
    Requirement.REQUIRED,
    Field.SendMax,
    Requirement.OPTIONAL,
    Field.Paths,
    Requirement.DEFAULT,
    Field.InvoiceID,
    Requirement.OPTIONAL,
    Field.DestinationTag,
    Requirement.OPTIONAL
  ]);

  static TxFormat TrustSet = new TxFormat(TransactionType.TrustSet, [
    Field.LimitAmount,
    Requirement.OPTIONAL,
    Field.QualityIn,
    Requirement.OPTIONAL,
    Field.QualityOut,
    Requirement.OPTIONAL
  ]);

  static TxFormat SQLStatement = new TxFormat(TransactionType.SQLStatement, [
    Field.Owner,
    Requirement.REQUIRED,
    Field.Tables,
    Requirement.REQUIRED,
    Field.Raw,
    Requirement.REQUIRED,
    Field.OpType,
    Requirement.REQUIRED,
    Field.AutoFillField,
    Requirement.OPTIONAL
  ]);


//  static TxFormat SQLStatement = new TxFormat(
//  TransactionType.SQLStatement,
//  Field.Owner,         Requirement.REQUIRED,
//  Field.Tables,        Requirement.REQUIRED,
//  Field.Raw,       	 Requirement.REQUIRED,
//  Field.AutoFillField, Requirement.OPTIONAL,
//  Field.TxCheckHash,	 Requirement.OPTIONAL,
//  Field.OpType, 		 Requirement.REQUIRED,
//  Field.TxnLgrSeq,	 Requirement.OPTIONAL,
//  Field.OriginalAddress,Requirement.OPTIONAL,
//  Field.CurTxHash,	 Requirement.OPTIONAL,
//  Field.FutureTxHash,	 Requirement.OPTIONAL);

}
